/** -*- adrian-c -*-
	 
	kover - Kover is an easy to use WYSIWYG CD cover printer with CDDB support.
	Copyright (C) 1999, 2000 by Denis Oliver Kropp
	Copyright (C) 2000, 2001 by Adrian Reber 
	
	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.
	
	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
	
	File: cddb_fill.h 

	Description: the cddb header

	Changes: 

	10 Jan 1999: Initial release

*/

#ifndef CDDB_FILL_H
#define CDDB_FILL_H

#include "kover.h"
#include "koverfile.h"

#define CDDB_PORT		80
 
#define KOVER_CDDB_LEVEL "3"  /* Current CDDB protocol level supported */

/**
  *@author Denis Oliver Kropp
  */

class track_info
{
public:
	track_info( int _track, int _min, int _sec, int _frame );

	QString	songname;	/* Name of song, dynamically allocated */
	int	min; //starting minute of the track
	int	sec; //starting second of the track
	int	length;		/* Length of track in seconds or Kbytes */
	int	start;		/* Starting position */
	int	track;		/* Physical track number */
};

class CD_Info
{
public:
	CD_Info();
	/* Artist's name */
	QString artist;
	/* Disc's name */
	QString cdname; 
	/* CDDB artist and CD name string */
	QString cdnames;	
	/* CDDB category */
	QString category;
	/* Number of tracks on the disc */
	int ntracks;	
	/* Total running time in seconds */
	int length; /* Total running time in seconds */

	/* struct trackinfo[ntracks] */
	QList<track_info>	trk;		
	/* CDDB ID which gets calculated */
	unsigned long cddb_id;	
};

class CDDB_Fill : public QObject
{
	Q_OBJECT
public: 
	CDDB_Fill( KoverFile* _kover_file );
	~CDDB_Fill();
	
	bool execute();

	void cdInfo();
	
signals:
	void statusText( const char* );
	 void update_id(unsigned long);

protected:
	int			openCD();
	void			closeCD();
	bool			readTOC();
	unsigned long	calcID();
	
	KoverFile* kover_file;
	CD_Info cdinfo;
	int cd_fd;
	
	int cddb_sum(int n);
	
	void parse_trails(char *ss);
	int cddb_connect();
	void cddb_disconnect();
	char *cddbHello();
	
	bool cddb_query();
	void cddb_readcdinfo(FILE *desc, bool local, bool save_as_file);
	
public:
	void setTitleAndContents();

private:

	bool getCDDBFromLocalFile();
	int CDDBSkipHTTP(int socket);
	char * make_cddb_request(char *query_me, bool use_auth=false);
	char cddb_msg[255];	/* Return message of server info */
	int code;		/* Return value for sending data to the server */
	int socket_1;		/* Descriptor for our first socket */
	int socket_2;		/* Descriptor for our second socket */
	int sock_mode;	/* Server read/write status */
	FILE *sk_1;		/* Stream descriptor for our first socket */
	FILE *sk_2;		/* Stream descriptor for our second socket */

};

#endif /* CDDB_FILL_H */
